Documentation
¶
Overview ¶
Index ¶
- Constants
- Variables
- func CanStream(processor Processor) bool
- func PreferStream(processor Processor) bool
- func TransformStream(processor Processor, reader io.Reader, writer io.Writer, opts ...Flag) error
- type ASCII85Decoding
- func (p ASCII85Decoding) Alias() []string
- func (p ASCII85Decoding) Description() string
- func (p ASCII85Decoding) FilterValue() string
- func (p ASCII85Decoding) Flags() []Flag
- func (p ASCII85Decoding) Name() string
- func (p ASCII85Decoding) Title() string
- func (p ASCII85Decoding) Transform(data []byte, _ ...Flag) (string, error)
- type ASCII85Encoding
- func (p ASCII85Encoding) Alias() []string
- func (p ASCII85Encoding) Description() string
- func (p ASCII85Encoding) FilterValue() string
- func (p ASCII85Encoding) Flags() []Flag
- func (p ASCII85Encoding) Name() string
- func (p ASCII85Encoding) Title() string
- func (p ASCII85Encoding) Transform(data []byte, _ ...Flag) (string, error)
- type Adler32
- type BLAKE2b
- func (p BLAKE2b) Alias() []string
- func (p BLAKE2b) CanStream() bool
- func (p BLAKE2b) Description() string
- func (p BLAKE2b) FilterValue() string
- func (p BLAKE2b) Flags() []Flag
- func (p BLAKE2b) Name() string
- func (p BLAKE2b) PreferStream() bool
- func (p BLAKE2b) Title() string
- func (p BLAKE2b) Transform(data []byte, f ...Flag) (string, error)
- func (p BLAKE2b) TransformStream(reader io.Reader, writer io.Writer, opts ...Flag) error
- type BLAKE2s
- func (p BLAKE2s) Alias() []string
- func (p BLAKE2s) CanStream() bool
- func (p BLAKE2s) Description() string
- func (p BLAKE2s) FilterValue() string
- func (p BLAKE2s) Flags() []Flag
- func (p BLAKE2s) Name() string
- func (p BLAKE2s) PreferStream() bool
- func (p BLAKE2s) Title() string
- func (p BLAKE2s) Transform(data []byte, _ ...Flag) (string, error)
- func (p BLAKE2s) TransformStream(reader io.Reader, writer io.Writer, opts ...Flag) error
- type Base32Decode
- func (p Base32Decode) Alias() []string
- func (p Base32Decode) Description() string
- func (p Base32Decode) FilterValue() string
- func (p Base32Decode) Flags() []Flag
- func (p Base32Decode) Name() string
- func (p Base32Decode) Title() string
- func (p Base32Decode) Transform(data []byte, _ ...Flag) (string, error)
- type Base32Encoding
- func (p Base32Encoding) Alias() []string
- func (p Base32Encoding) Description() string
- func (p Base32Encoding) FilterValue() string
- func (p Base32Encoding) Flags() []Flag
- func (p Base32Encoding) Name() string
- func (p Base32Encoding) Title() string
- func (p Base32Encoding) Transform(data []byte, _ ...Flag) (string, error)
- type Base58Decode
- func (p Base58Decode) Alias() []string
- func (p Base58Decode) Description() string
- func (p Base58Decode) FilterValue() string
- func (p Base58Decode) Flags() []Flag
- func (p Base58Decode) Name() string
- func (p Base58Decode) Title() string
- func (p Base58Decode) Transform(data []byte, f ...Flag) (string, error)
- type Base58Encode
- func (p Base58Encode) Alias() []string
- func (p Base58Encode) Description() string
- func (p Base58Encode) FilterValue() string
- func (p Base58Encode) Flags() []Flag
- func (p Base58Encode) Name() string
- func (p Base58Encode) Title() string
- func (p Base58Encode) Transform(data []byte, f ...Flag) (string, error)
- type Base62Decode
- func (p Base62Decode) Alias() []string
- func (p Base62Decode) Description() string
- func (p Base62Decode) FilterValue() string
- func (p Base62Decode) Flags() []Flag
- func (p Base62Decode) Name() string
- func (p Base62Decode) Title() string
- func (p Base62Decode) Transform(data []byte, _ ...Flag) (string, error)
- type Base62Encode
- func (p Base62Encode) Alias() []string
- func (p Base62Encode) Description() string
- func (p Base62Encode) FilterValue() string
- func (p Base62Encode) Flags() []Flag
- func (p Base62Encode) Name() string
- func (p Base62Encode) Title() string
- func (p Base62Encode) Transform(data []byte, f ...Flag) (string, error)
- type Base64Decode
- func (p Base64Decode) Alias() []string
- func (p Base64Decode) Description() string
- func (p Base64Decode) FilterValue() string
- func (p Base64Decode) Flags() []Flag
- func (p Base64Decode) Name() string
- func (p Base64Decode) Title() string
- func (p Base64Decode) Transform(data []byte, f ...Flag) (string, error)
- type Base64Encode
- func (p Base64Encode) Alias() []string
- func (p Base64Encode) Description() string
- func (p Base64Encode) FilterValue() string
- func (p Base64Encode) Flags() []Flag
- func (p Base64Encode) Name() string
- func (p Base64Encode) Title() string
- func (p Base64Encode) Transform(data []byte, f ...Flag) (string, error)
- type Base64URLDecode
- func (p Base64URLDecode) Alias() []string
- func (p Base64URLDecode) Description() string
- func (p Base64URLDecode) FilterValue() string
- func (p Base64URLDecode) Flags() []Flag
- func (p Base64URLDecode) Name() string
- func (p Base64URLDecode) Title() string
- func (p Base64URLDecode) Transform(data []byte, f ...Flag) (string, error)
- type Base64URLEncode
- func (p Base64URLEncode) Alias() []string
- func (p Base64URLEncode) Description() string
- func (p Base64URLEncode) FilterValue() string
- func (p Base64URLEncode) Flags() []Flag
- func (p Base64URLEncode) Name() string
- func (p Base64URLEncode) Title() string
- func (p Base64URLEncode) Transform(data []byte, f ...Flag) (string, error)
- type Bcrypt
- type CRC32
- type Camel
- type ConfigurableStreamingProcessor
- type CountCharacters
- func (p CountCharacters) Alias() []string
- func (p CountCharacters) Description() string
- func (p CountCharacters) FilterValue() string
- func (p CountCharacters) Flags() []Flag
- func (p CountCharacters) GetStreamingConfig() StreamingConfig
- func (p CountCharacters) Name() string
- func (p CountCharacters) Title() string
- func (p CountCharacters) Transform(data []byte, _ ...Flag) (string, error)
- type CountLines
- func (p CountLines) Alias() []string
- func (p CountLines) Description() string
- func (p CountLines) FilterValue() string
- func (p CountLines) Flags() []Flag
- func (p CountLines) GetStreamingConfig() StreamingConfig
- func (p CountLines) Name() string
- func (p CountLines) Title() string
- func (p CountLines) Transform(data []byte, _ ...Flag) (string, error)
- type CountWords
- func (p CountWords) Alias() []string
- func (p CountWords) Description() string
- func (p CountWords) FilterValue() string
- func (p CountWords) Flags() []Flag
- func (p CountWords) GetStreamingConfig() StreamingConfig
- func (p CountWords) Name() string
- func (p CountWords) Title() string
- func (p CountWords) Transform(data []byte, _ ...Flag) (string, error)
- type CrockfordBase32Decode
- func (p CrockfordBase32Decode) Alias() []string
- func (p CrockfordBase32Decode) Description() string
- func (p CrockfordBase32Decode) FilterValue() string
- func (p CrockfordBase32Decode) Flags() []Flag
- func (p CrockfordBase32Decode) Name() string
- func (p CrockfordBase32Decode) Title() string
- func (p CrockfordBase32Decode) Transform(data []byte, f ...Flag) (string, error)
- type CrockfordBase32Encode
- func (p CrockfordBase32Encode) Alias() []string
- func (p CrockfordBase32Encode) Description() string
- func (p CrockfordBase32Encode) FilterValue() string
- func (p CrockfordBase32Encode) Flags() []Flag
- func (p CrockfordBase32Encode) Name() string
- func (p CrockfordBase32Encode) Title() string
- func (p CrockfordBase32Encode) Transform(data []byte, f ...Flag) (string, error)
- type DefaultStreamingProcessor
- func (d DefaultStreamingProcessor) Alias() []string
- func (d DefaultStreamingProcessor) CanStream() bool
- func (d DefaultStreamingProcessor) Description() string
- func (d DefaultStreamingProcessor) FilterValue() string
- func (d DefaultStreamingProcessor) Flags() []Flag
- func (d DefaultStreamingProcessor) Name() string
- func (d DefaultStreamingProcessor) PreferStream() bool
- func (d DefaultStreamingProcessor) Title() string
- func (d DefaultStreamingProcessor) Transform(data []byte, opts ...Flag) (string, error)
- func (d DefaultStreamingProcessor) TransformStream(reader io.Reader, writer io.Writer, opts ...Flag) error
- type EscapeQuotes
- func (p EscapeQuotes) Alias() []string
- func (p EscapeQuotes) Description() string
- func (p EscapeQuotes) FilterValue() string
- func (p EscapeQuotes) Flags() []Flag
- func (p EscapeQuotes) Name() string
- func (p EscapeQuotes) Title() string
- func (p EscapeQuotes) Transform(data []byte, f ...Flag) (string, error)
- type ExtractEmails
- func (p ExtractEmails) Alias() []string
- func (p ExtractEmails) Description() string
- func (p ExtractEmails) FilterValue() string
- func (p ExtractEmails) Flags() []Flag
- func (p ExtractEmails) Name() string
- func (p ExtractEmails) Title() string
- func (p ExtractEmails) Transform(data []byte, f ...Flag) (string, error)
- type ExtractIPs
- type ExtractURLs
- type Flag
- type FlagType
- type FormatJSON
- type HTMLDecode
- type HTMLEncode
- type HexDecode
- func (p HexDecode) Alias() []string
- func (p HexDecode) Description() string
- func (p HexDecode) FilterValue() string
- func (p HexDecode) Flags() []Flag
- func (p HexDecode) GetStreamingConfig() StreamingConfig
- func (p HexDecode) Name() string
- func (p HexDecode) Title() string
- func (p HexDecode) Transform(data []byte, _ ...Flag) (string, error)
- type HexEncode
- func (p HexEncode) Alias() []string
- func (p HexEncode) Description() string
- func (p HexEncode) FilterValue() string
- func (p HexEncode) Flags() []Flag
- func (p HexEncode) GetStreamingConfig() StreamingConfig
- func (p HexEncode) Name() string
- func (p HexEncode) Title() string
- func (p HexEncode) Transform(data []byte, _ ...Flag) (string, error)
- type HexToRGB
- type JSONEscape
- type JSONToMSGPACK
- func (p JSONToMSGPACK) Alias() []string
- func (p JSONToMSGPACK) Description() string
- func (p JSONToMSGPACK) FilterValue() string
- func (p JSONToMSGPACK) Flags() []Flag
- func (p JSONToMSGPACK) Name() string
- func (p JSONToMSGPACK) Title() string
- func (p JSONToMSGPACK) Transform(data []byte, _ ...Flag) (string, error)
- type JSONToYAML
- type JSONUnescape
- func (p JSONUnescape) Alias() []string
- func (p JSONUnescape) Description() string
- func (p JSONUnescape) FilterValue() string
- func (p JSONUnescape) Flags() []Flag
- func (p JSONUnescape) Name() string
- func (p JSONUnescape) Title() string
- func (p JSONUnescape) Transform(data []byte, f ...Flag) (string, error)
- type Kebab
- type Lower
- func (p Lower) Alias() []string
- func (p Lower) Description() string
- func (p Lower) FilterValue() string
- func (p Lower) Flags() []Flag
- func (p Lower) GetStreamingConfig() StreamingConfig
- func (p Lower) Name() string
- func (p Lower) Title() string
- func (p Lower) Transform(data []byte, _ ...Flag) (string, error)
- type MD5
- type MSGPACKToJSON
- func (p MSGPACKToJSON) Alias() []string
- func (p MSGPACKToJSON) Description() string
- func (p MSGPACKToJSON) FilterValue() string
- func (p MSGPACKToJSON) Flags() []Flag
- func (p MSGPACKToJSON) Name() string
- func (p MSGPACKToJSON) Title() string
- func (p MSGPACKToJSON) Transform(data []byte, _ ...Flag) (string, error)
- type Markdown
- type MorseCodeDecode
- func (p MorseCodeDecode) Alias() []string
- func (p MorseCodeDecode) Description() string
- func (p MorseCodeDecode) FilterValue() string
- func (p MorseCodeDecode) Flags() []Flag
- func (p MorseCodeDecode) Name() string
- func (p MorseCodeDecode) Title() string
- func (p MorseCodeDecode) Transform(data []byte, f ...Flag) (string, error)
- type MorseCodeEncode
- func (p MorseCodeEncode) Alias() []string
- func (p MorseCodeEncode) Description() string
- func (p MorseCodeEncode) FilterValue() string
- func (p MorseCodeEncode) Flags() []Flag
- func (p MorseCodeEncode) Name() string
- func (p MorseCodeEncode) Title() string
- func (p MorseCodeEncode) Transform(data []byte, _ ...Flag) (string, error)
- type NumberLines
- func (p NumberLines) Alias() []string
- func (p NumberLines) Description() string
- func (p NumberLines) FilterValue() string
- func (p NumberLines) Flags() []Flag
- func (p NumberLines) GetStreamingConfig() StreamingConfig
- func (p NumberLines) Name() string
- func (p NumberLines) Title() string
- func (p NumberLines) Transform(data []byte, _ ...Flag) (string, error)
- type Pascal
- type Processor
- type QRCode
- func (p QRCode) Alias() []string
- func (p QRCode) Description() string
- func (p QRCode) FilterValue() string
- func (p QRCode) Flags() []Flag
- func (p QRCode) GetStreamingConfig() StreamingConfig
- func (p QRCode) Name() string
- func (p QRCode) Title() string
- func (p QRCode) Transform(data []byte, f ...Flag) (string, error)
- type ROT13
- type RemoveNewLines
- func (p RemoveNewLines) Alias() []string
- func (p RemoveNewLines) Description() string
- func (p RemoveNewLines) FilterValue() string
- func (p RemoveNewLines) Flags() []Flag
- func (p RemoveNewLines) Name() string
- func (p RemoveNewLines) Title() string
- func (p RemoveNewLines) Transform(data []byte, f ...Flag) (string, error)
- type RemoveSpaces
- func (p RemoveSpaces) Alias() []string
- func (p RemoveSpaces) Description() string
- func (p RemoveSpaces) FilterValue() string
- func (p RemoveSpaces) Flags() []Flag
- func (p RemoveSpaces) Name() string
- func (p RemoveSpaces) Title() string
- func (p RemoveSpaces) Transform(data []byte, f ...Flag) (string, error)
- type Reverse
- type ReverseLines
- func (p ReverseLines) Alias() []string
- func (p ReverseLines) Description() string
- func (p ReverseLines) FilterValue() string
- func (p ReverseLines) Flags() []Flag
- func (p ReverseLines) GetStreamingConfig() StreamingConfig
- func (p ReverseLines) Name() string
- func (p ReverseLines) Title() string
- func (p ReverseLines) Transform(data []byte, _ ...Flag) (string, error)
- type SHA1
- func (p SHA1) Alias() []string
- func (p SHA1) Description() string
- func (p SHA1) FilterValue() string
- func (p SHA1) Flags() []Flag
- func (p SHA1) GetStreamingConfig() StreamingConfig
- func (p SHA1) Name() string
- func (p SHA1) Title() string
- func (p SHA1) Transform(data []byte, _ ...Flag) (string, error)
- type SHA224
- func (p SHA224) Alias() []string
- func (p SHA224) Description() string
- func (p SHA224) FilterValue() string
- func (p SHA224) Flags() []Flag
- func (p SHA224) GetStreamingConfig() StreamingConfig
- func (p SHA224) Name() string
- func (p SHA224) Title() string
- func (p SHA224) Transform(data []byte, _ ...Flag) (string, error)
- type SHA256
- func (p SHA256) Alias() []string
- func (p SHA256) Description() string
- func (p SHA256) FilterValue() string
- func (p SHA256) Flags() []Flag
- func (p SHA256) GetStreamingConfig() StreamingConfig
- func (p SHA256) Name() string
- func (p SHA256) Title() string
- func (p SHA256) Transform(data []byte, _ ...Flag) (string, error)
- type SHA384
- func (p SHA384) Alias() []string
- func (p SHA384) Description() string
- func (p SHA384) FilterValue() string
- func (p SHA384) Flags() []Flag
- func (p SHA384) GetStreamingConfig() StreamingConfig
- func (p SHA384) Name() string
- func (p SHA384) Title() string
- func (p SHA384) Transform(data []byte, _ ...Flag) (string, error)
- type SHA512
- func (p SHA512) Alias() []string
- func (p SHA512) Description() string
- func (p SHA512) FilterValue() string
- func (p SHA512) Flags() []Flag
- func (p SHA512) GetStreamingConfig() StreamingConfig
- func (p SHA512) Name() string
- func (p SHA512) Title() string
- func (p SHA512) Transform(data []byte, _ ...Flag) (string, error)
- type ShuffleLines
- func (p ShuffleLines) Alias() []string
- func (p ShuffleLines) Description() string
- func (p ShuffleLines) FilterValue() string
- func (p ShuffleLines) Flags() []Flag
- func (p ShuffleLines) Name() string
- func (p ShuffleLines) Title() string
- func (p ShuffleLines) Transform(data []byte, _ ...Flag) (string, error)
- type Slug
- type Snake
- type SortLines
- func (p SortLines) Alias() []string
- func (p SortLines) Description() string
- func (p SortLines) FilterValue() string
- func (p SortLines) Flags() []Flag
- func (p SortLines) GetStreamingConfig() StreamingConfig
- func (p SortLines) Name() string
- func (p SortLines) Title() string
- func (p SortLines) Transform(data []byte, _ ...Flag) (string, error)
- type StreamingCapable
- type StreamingConfig
- type StreamingProcessor
- type Title
- type URLDecode
- type URLEncode
- type UniqueLines
- func (p UniqueLines) Alias() []string
- func (p UniqueLines) Description() string
- func (p UniqueLines) FilterValue() string
- func (p UniqueLines) Flags() []Flag
- func (p UniqueLines) GetStreamingConfig() StreamingConfig
- func (p UniqueLines) Name() string
- func (p UniqueLines) Title() string
- func (p UniqueLines) Transform(data []byte, _ ...Flag) (string, error)
- type Upper
- func (p Upper) Alias() []string
- func (p Upper) Description() string
- func (p Upper) FilterValue() string
- func (p Upper) Flags() []Flag
- func (p Upper) GetStreamingConfig() StreamingConfig
- func (p Upper) Name() string
- func (p Upper) Title() string
- func (p Upper) Transform(data []byte, _ ...Flag) (string, error)
- type XXH32
- type XXH64
- type XXH128
- type YAMLToJSON
- type Zeropad
Constants ¶
const ( FlagInt = FlagType("Int") FlagUint = FlagType("Uint") FlagBool = FlagType("Bool") FlagString = FlagType("String") )
Variables ¶
var DefaultStreamingConfig = StreamingConfig{ ChunkSize: 64 * 1024, BufferOutput: false, LineByLine: false, }
DefaultStreamingConfig provides sensible defaults for streaming
var List = []list.Item{ Adler32{}, ASCII85Decoding{}, ASCII85Encoding{}, Base32Decode{}, Base32Encoding{}, Base58Decode{}, Base58Encode{}, Base62Decode{}, Base62Encode{}, Base64Decode{}, Base64Encode{}, Base64URLDecode{}, Base64URLEncode{}, Bcrypt{}, BLAKE2b{}, BLAKE2s{}, Camel{}, CountCharacters{}, CountLines{}, CountWords{}, CRC32{}, CrockfordBase32Decode{}, CrockfordBase32Encode{}, EscapeQuotes{}, ExtractEmails{}, ExtractURLs{}, ExtractIPs{}, FormatJSON{}, HexDecode{}, HexEncode{}, HexToRGB{}, HTMLDecode{}, HTMLEncode{}, JSONEscape{}, JSONToMSGPACK{}, JSONToYAML{}, JSONUnescape{}, Kebab{}, Lower{}, Markdown{}, MorseCodeEncode{}, MorseCodeDecode{}, MD5{}, MSGPACKToJSON{}, NumberLines{}, Pascal{}, QRCode{}, RemoveNewLines{}, RemoveSpaces{}, Reverse{}, ReverseLines{}, ROT13{}, SHA1{}, SHA224{}, SHA256{}, SHA384{}, SHA512{}, ShuffleLines{}, Slug{}, Snake{}, SortLines{}, Title{}, UniqueLines{}, Upper{}, URLDecode{}, URLEncode{}, XXH32{}, XXH64{}, XXH128{}, YAMLToJSON{}, Zeropad{}, }
Functions ¶
func CanStream ¶ added in v0.2.29
CanStream returns true if a processor can handle streaming All processors can stream using the central TransformStream function
func PreferStream ¶ added in v0.2.29
PreferStream returns true if a processor benefits from streaming This is useful for large files or processors that don't need full input
Types ¶
type ASCII85Decoding ¶ added in v0.2.11
type ASCII85Decoding struct{}
ASCII85Decoding decodes Ascii85 (aka Base85) to plain text.
func (ASCII85Decoding) Alias ¶ added in v0.2.11
func (p ASCII85Decoding) Alias() []string
func (ASCII85Decoding) Description ¶ added in v0.2.11
func (p ASCII85Decoding) Description() string
func (ASCII85Decoding) FilterValue ¶ added in v0.2.11
func (p ASCII85Decoding) FilterValue() string
func (ASCII85Decoding) Flags ¶ added in v0.2.11
func (p ASCII85Decoding) Flags() []Flag
func (ASCII85Decoding) Name ¶ added in v0.2.11
func (p ASCII85Decoding) Name() string
func (ASCII85Decoding) Title ¶ added in v0.2.11
func (p ASCII85Decoding) Title() string
type ASCII85Encoding ¶ added in v0.2.11
type ASCII85Encoding struct{}
ASCII85Encoding encodes plain text to Ascii85 (aka Base85)
func (ASCII85Encoding) Alias ¶ added in v0.2.11
func (p ASCII85Encoding) Alias() []string
func (ASCII85Encoding) Description ¶ added in v0.2.11
func (p ASCII85Encoding) Description() string
func (ASCII85Encoding) FilterValue ¶ added in v0.2.11
func (p ASCII85Encoding) FilterValue() string
func (ASCII85Encoding) Flags ¶ added in v0.2.11
func (p ASCII85Encoding) Flags() []Flag
func (ASCII85Encoding) Name ¶ added in v0.2.11
func (p ASCII85Encoding) Name() string
func (ASCII85Encoding) Title ¶ added in v0.2.11
func (p ASCII85Encoding) Title() string
type Adler32 ¶ added in v0.2.29
type Adler32 struct{}
Adler32 generates Adler32 checksum
func (Adler32) Description ¶ added in v0.2.29
func (Adler32) FilterValue ¶ added in v0.2.29
type BLAKE2b ¶ added in v0.2.29
type BLAKE2b struct{}
BLAKE2b generates BLAKE2b hash
func (BLAKE2b) Description ¶ added in v0.2.29
func (BLAKE2b) FilterValue ¶ added in v0.2.29
func (BLAKE2b) PreferStream ¶ added in v0.2.29
type BLAKE2s ¶ added in v0.2.29
type BLAKE2s struct{}
BLAKE2s generates BLAKE2s hash
func (BLAKE2s) Description ¶ added in v0.2.29
func (BLAKE2s) FilterValue ¶ added in v0.2.29
func (BLAKE2s) PreferStream ¶ added in v0.2.29
type Base32Decode ¶ added in v0.2.0
type Base32Decode struct{}
Base32Decode decodes string from Base32 string to plain text.
func (Base32Decode) Alias ¶ added in v0.2.0
func (p Base32Decode) Alias() []string
func (Base32Decode) Description ¶ added in v0.2.0
func (p Base32Decode) Description() string
func (Base32Decode) FilterValue ¶ added in v0.2.0
func (p Base32Decode) FilterValue() string
func (Base32Decode) Flags ¶ added in v0.2.0
func (p Base32Decode) Flags() []Flag
func (Base32Decode) Name ¶ added in v0.2.0
func (p Base32Decode) Name() string
func (Base32Decode) Title ¶ added in v0.2.0
func (p Base32Decode) Title() string
type Base32Encoding ¶ added in v0.2.0
type Base32Encoding struct{}
Base32Encoding encodes plain text to Base32 string.
func (Base32Encoding) Alias ¶ added in v0.2.0
func (p Base32Encoding) Alias() []string
func (Base32Encoding) Description ¶ added in v0.2.0
func (p Base32Encoding) Description() string
func (Base32Encoding) FilterValue ¶ added in v0.2.0
func (p Base32Encoding) FilterValue() string
func (Base32Encoding) Flags ¶ added in v0.2.0
func (p Base32Encoding) Flags() []Flag
func (Base32Encoding) Name ¶ added in v0.2.0
func (p Base32Encoding) Name() string
func (Base32Encoding) Title ¶ added in v0.2.0
func (p Base32Encoding) Title() string
type Base58Decode ¶ added in v0.2.29
type Base58Decode struct{}
func (Base58Decode) Alias ¶ added in v0.2.29
func (p Base58Decode) Alias() []string
func (Base58Decode) Description ¶ added in v0.2.29
func (p Base58Decode) Description() string
func (Base58Decode) FilterValue ¶ added in v0.2.29
func (p Base58Decode) FilterValue() string
func (Base58Decode) Flags ¶ added in v0.2.29
func (p Base58Decode) Flags() []Flag
func (Base58Decode) Name ¶ added in v0.2.29
func (p Base58Decode) Name() string
func (Base58Decode) Title ¶ added in v0.2.29
func (p Base58Decode) Title() string
type Base58Encode ¶ added in v0.2.29
type Base58Encode struct{}
func (Base58Encode) Alias ¶ added in v0.2.29
func (p Base58Encode) Alias() []string
func (Base58Encode) Description ¶ added in v0.2.29
func (p Base58Encode) Description() string
func (Base58Encode) FilterValue ¶ added in v0.2.29
func (p Base58Encode) FilterValue() string
func (Base58Encode) Flags ¶ added in v0.2.29
func (p Base58Encode) Flags() []Flag
func (Base58Encode) Name ¶ added in v0.2.29
func (p Base58Encode) Name() string
func (Base58Encode) Title ¶ added in v0.2.29
func (p Base58Encode) Title() string
type Base62Decode ¶ added in v0.2.29
type Base62Decode struct{}
func (Base62Decode) Alias ¶ added in v0.2.29
func (p Base62Decode) Alias() []string
func (Base62Decode) Description ¶ added in v0.2.29
func (p Base62Decode) Description() string
func (Base62Decode) FilterValue ¶ added in v0.2.29
func (p Base62Decode) FilterValue() string
func (Base62Decode) Flags ¶ added in v0.2.29
func (p Base62Decode) Flags() []Flag
func (Base62Decode) Name ¶ added in v0.2.29
func (p Base62Decode) Name() string
func (Base62Decode) Title ¶ added in v0.2.29
func (p Base62Decode) Title() string
type Base62Encode ¶ added in v0.2.29
type Base62Encode struct{}
func (Base62Encode) Alias ¶ added in v0.2.29
func (p Base62Encode) Alias() []string
func (Base62Encode) Description ¶ added in v0.2.29
func (p Base62Encode) Description() string
func (Base62Encode) FilterValue ¶ added in v0.2.29
func (p Base62Encode) FilterValue() string
func (Base62Encode) Flags ¶ added in v0.2.29
func (p Base62Encode) Flags() []Flag
func (Base62Encode) Name ¶ added in v0.2.29
func (p Base62Encode) Name() string
func (Base62Encode) Title ¶ added in v0.2.29
func (p Base62Encode) Title() string
type Base64Decode ¶
type Base64Decode struct{}
Base64Decode decodes string from Base64 string to plain text.
func (Base64Decode) Alias ¶ added in v0.2.0
func (p Base64Decode) Alias() []string
func (Base64Decode) Description ¶ added in v0.2.0
func (p Base64Decode) Description() string
func (Base64Decode) FilterValue ¶ added in v0.2.0
func (p Base64Decode) FilterValue() string
func (Base64Decode) Flags ¶ added in v0.2.0
func (p Base64Decode) Flags() []Flag
func (Base64Decode) Name ¶ added in v0.2.0
func (p Base64Decode) Name() string
func (Base64Decode) Title ¶ added in v0.2.0
func (p Base64Decode) Title() string
type Base64Encode ¶
type Base64Encode struct{}
Base64Encode encodes plain text to Base64 string.
func (Base64Encode) Alias ¶ added in v0.2.0
func (p Base64Encode) Alias() []string
func (Base64Encode) Description ¶ added in v0.2.0
func (p Base64Encode) Description() string
func (Base64Encode) FilterValue ¶ added in v0.2.0
func (p Base64Encode) FilterValue() string
func (Base64Encode) Flags ¶ added in v0.2.0
func (p Base64Encode) Flags() []Flag
func (Base64Encode) Name ¶ added in v0.2.0
func (p Base64Encode) Name() string
func (Base64Encode) Title ¶ added in v0.2.0
func (p Base64Encode) Title() string
type Base64URLDecode ¶ added in v0.2.4
type Base64URLDecode struct{}
Base64URLDecode decodes Base64 URL string to plain text.
func (Base64URLDecode) Alias ¶ added in v0.2.4
func (p Base64URLDecode) Alias() []string
func (Base64URLDecode) Description ¶ added in v0.2.4
func (p Base64URLDecode) Description() string
func (Base64URLDecode) FilterValue ¶ added in v0.2.4
func (p Base64URLDecode) FilterValue() string
func (Base64URLDecode) Flags ¶ added in v0.2.4
func (p Base64URLDecode) Flags() []Flag
func (Base64URLDecode) Name ¶ added in v0.2.4
func (p Base64URLDecode) Name() string
func (Base64URLDecode) Title ¶ added in v0.2.4
func (p Base64URLDecode) Title() string
type Base64URLEncode ¶ added in v0.2.4
type Base64URLEncode struct{}
Base64URLEncode encodes plain text to Base64 URL string.
func (Base64URLEncode) Alias ¶ added in v0.2.4
func (p Base64URLEncode) Alias() []string
func (Base64URLEncode) Description ¶ added in v0.2.4
func (p Base64URLEncode) Description() string
func (Base64URLEncode) FilterValue ¶ added in v0.2.4
func (p Base64URLEncode) FilterValue() string
func (Base64URLEncode) Flags ¶ added in v0.2.4
func (p Base64URLEncode) Flags() []Flag
func (Base64URLEncode) Name ¶ added in v0.2.4
func (p Base64URLEncode) Name() string
func (Base64URLEncode) Title ¶ added in v0.2.4
func (p Base64URLEncode) Title() string
type Bcrypt ¶ added in v0.2.0
type Bcrypt struct{}
Bcrypt encodes string to bcrypt.
func (Bcrypt) Description ¶ added in v0.2.0
func (Bcrypt) FilterValue ¶ added in v0.2.0
type CRC32 ¶ added in v0.2.29
type CRC32 struct{}
CRC32 generates CRC32 checksum
func (CRC32) Description ¶ added in v0.2.29
func (CRC32) FilterValue ¶ added in v0.2.29
type Camel ¶ added in v0.2.0
type Camel struct{}
Camel convert string to camelCase. Example: "this is string" to "thisIsString".
func (Camel) Description ¶ added in v0.2.0
func (Camel) FilterValue ¶ added in v0.2.0
type ConfigurableStreamingProcessor ¶ added in v0.2.29
type ConfigurableStreamingProcessor interface {
Processor
// GetStreamingConfig returns the streaming configuration for this processor
GetStreamingConfig() StreamingConfig
}
ConfigurableStreamingProcessor is an optional interface that processors can implement to customize their streaming behavior
type CountCharacters ¶ added in v0.2.0
type CountCharacters struct{}
CountCharacters count number of characters including spaces.
func (CountCharacters) Alias ¶ added in v0.2.0
func (p CountCharacters) Alias() []string
func (CountCharacters) Description ¶ added in v0.2.0
func (p CountCharacters) Description() string
func (CountCharacters) FilterValue ¶ added in v0.2.0
func (p CountCharacters) FilterValue() string
func (CountCharacters) Flags ¶ added in v0.2.0
func (p CountCharacters) Flags() []Flag
func (CountCharacters) GetStreamingConfig ¶ added in v0.2.29
func (p CountCharacters) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for character counting
func (CountCharacters) Name ¶ added in v0.2.0
func (p CountCharacters) Name() string
func (CountCharacters) Title ¶ added in v0.2.0
func (p CountCharacters) Title() string
type CountLines ¶
type CountLines struct{}
CountLines counts number of words in string. Example: "line 1\n line 2" = 2.
func (CountLines) Alias ¶ added in v0.2.0
func (p CountLines) Alias() []string
func (CountLines) Description ¶ added in v0.2.0
func (p CountLines) Description() string
func (CountLines) FilterValue ¶ added in v0.2.0
func (p CountLines) FilterValue() string
func (CountLines) Flags ¶ added in v0.2.0
func (p CountLines) Flags() []Flag
func (CountLines) GetStreamingConfig ¶ added in v0.2.29
func (p CountLines) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for line counting
func (CountLines) Name ¶ added in v0.2.0
func (p CountLines) Name() string
func (CountLines) Title ¶ added in v0.2.0
func (p CountLines) Title() string
type CountWords ¶
type CountWords struct{}
CountWords counts number of words in string. Example: "hello world" = 2.
func (CountWords) Alias ¶ added in v0.2.0
func (p CountWords) Alias() []string
func (CountWords) Description ¶ added in v0.2.0
func (p CountWords) Description() string
func (CountWords) FilterValue ¶ added in v0.2.0
func (p CountWords) FilterValue() string
func (CountWords) Flags ¶ added in v0.2.0
func (p CountWords) Flags() []Flag
func (CountWords) GetStreamingConfig ¶ added in v0.2.29
func (p CountWords) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for word counting
func (CountWords) Name ¶ added in v0.2.0
func (p CountWords) Name() string
func (CountWords) Title ¶ added in v0.2.0
func (p CountWords) Title() string
type CrockfordBase32Decode ¶ added in v0.2.29
type CrockfordBase32Decode struct{}
func (CrockfordBase32Decode) Alias ¶ added in v0.2.29
func (p CrockfordBase32Decode) Alias() []string
func (CrockfordBase32Decode) Description ¶ added in v0.2.29
func (p CrockfordBase32Decode) Description() string
func (CrockfordBase32Decode) FilterValue ¶ added in v0.2.29
func (p CrockfordBase32Decode) FilterValue() string
func (CrockfordBase32Decode) Flags ¶ added in v0.2.29
func (p CrockfordBase32Decode) Flags() []Flag
func (CrockfordBase32Decode) Name ¶ added in v0.2.29
func (p CrockfordBase32Decode) Name() string
func (CrockfordBase32Decode) Title ¶ added in v0.2.29
func (p CrockfordBase32Decode) Title() string
type CrockfordBase32Encode ¶ added in v0.2.29
type CrockfordBase32Encode struct{}
func (CrockfordBase32Encode) Alias ¶ added in v0.2.29
func (p CrockfordBase32Encode) Alias() []string
func (CrockfordBase32Encode) Description ¶ added in v0.2.29
func (p CrockfordBase32Encode) Description() string
func (CrockfordBase32Encode) FilterValue ¶ added in v0.2.29
func (p CrockfordBase32Encode) FilterValue() string
func (CrockfordBase32Encode) Flags ¶ added in v0.2.29
func (p CrockfordBase32Encode) Flags() []Flag
func (CrockfordBase32Encode) Name ¶ added in v0.2.29
func (p CrockfordBase32Encode) Name() string
func (CrockfordBase32Encode) Title ¶ added in v0.2.29
func (p CrockfordBase32Encode) Title() string
type DefaultStreamingProcessor ¶ added in v0.2.29
type DefaultStreamingProcessor struct{}
func (DefaultStreamingProcessor) Alias ¶ added in v0.2.29
func (d DefaultStreamingProcessor) Alias() []string
func (DefaultStreamingProcessor) CanStream ¶ added in v0.2.29
func (d DefaultStreamingProcessor) CanStream() bool
func (DefaultStreamingProcessor) Description ¶ added in v0.2.29
func (d DefaultStreamingProcessor) Description() string
func (DefaultStreamingProcessor) FilterValue ¶ added in v0.2.29
func (d DefaultStreamingProcessor) FilterValue() string
func (DefaultStreamingProcessor) Flags ¶ added in v0.2.29
func (d DefaultStreamingProcessor) Flags() []Flag
func (DefaultStreamingProcessor) Name ¶ added in v0.2.29
func (d DefaultStreamingProcessor) Name() string
func (DefaultStreamingProcessor) PreferStream ¶ added in v0.2.29
func (d DefaultStreamingProcessor) PreferStream() bool
func (DefaultStreamingProcessor) Title ¶ added in v0.2.29
func (d DefaultStreamingProcessor) Title() string
func (DefaultStreamingProcessor) Transform ¶ added in v0.2.29
func (d DefaultStreamingProcessor) Transform(data []byte, opts ...Flag) (string, error)
func (DefaultStreamingProcessor) TransformStream ¶ added in v0.2.29
type EscapeQuotes ¶ added in v0.2.20
type EscapeQuotes struct{}
EscapeQuotes escapes quotes from a given string Example: "test" to \"test\".
func (EscapeQuotes) Alias ¶ added in v0.2.20
func (p EscapeQuotes) Alias() []string
func (EscapeQuotes) Description ¶ added in v0.2.20
func (p EscapeQuotes) Description() string
func (EscapeQuotes) FilterValue ¶ added in v0.2.20
func (p EscapeQuotes) FilterValue() string
func (EscapeQuotes) Flags ¶ added in v0.2.20
func (p EscapeQuotes) Flags() []Flag
func (EscapeQuotes) Name ¶ added in v0.2.20
func (p EscapeQuotes) Name() string
func (EscapeQuotes) Title ¶ added in v0.2.20
func (p EscapeQuotes) Title() string
type ExtractEmails ¶ added in v0.2.0
type ExtractEmails struct{}
ExtractEmails will pluck all the valid emails from a given text.
func (ExtractEmails) Alias ¶ added in v0.2.0
func (p ExtractEmails) Alias() []string
func (ExtractEmails) Description ¶ added in v0.2.0
func (p ExtractEmails) Description() string
func (ExtractEmails) FilterValue ¶ added in v0.2.0
func (p ExtractEmails) FilterValue() string
func (ExtractEmails) Flags ¶ added in v0.2.0
func (p ExtractEmails) Flags() []Flag
func (ExtractEmails) Name ¶ added in v0.2.0
func (p ExtractEmails) Name() string
func (ExtractEmails) Title ¶ added in v0.2.0
func (p ExtractEmails) Title() string
type ExtractIPs ¶ added in v0.2.11
type ExtractIPs struct{}
ExtractIPs extracts ipv4 and ipv6 from string.
func (ExtractIPs) Alias ¶ added in v0.2.11
func (p ExtractIPs) Alias() []string
func (ExtractIPs) Description ¶ added in v0.2.11
func (p ExtractIPs) Description() string
func (ExtractIPs) FilterValue ¶ added in v0.2.11
func (p ExtractIPs) FilterValue() string
func (ExtractIPs) Flags ¶ added in v0.2.11
func (p ExtractIPs) Flags() []Flag
func (ExtractIPs) Name ¶ added in v0.2.11
func (p ExtractIPs) Name() string
func (ExtractIPs) Title ¶ added in v0.2.11
func (p ExtractIPs) Title() string
type ExtractURLs ¶ added in v0.2.20
type ExtractURLs struct{}
ExtractURLs decode url string.
func (ExtractURLs) Alias ¶ added in v0.2.20
func (p ExtractURLs) Alias() []string
func (ExtractURLs) Description ¶ added in v0.2.20
func (p ExtractURLs) Description() string
func (ExtractURLs) FilterValue ¶ added in v0.2.20
func (p ExtractURLs) FilterValue() string
func (ExtractURLs) Flags ¶ added in v0.2.20
func (p ExtractURLs) Flags() []Flag
func (ExtractURLs) Name ¶ added in v0.2.20
func (p ExtractURLs) Name() string
func (ExtractURLs) Title ¶ added in v0.2.20
func (p ExtractURLs) Title() string
type Flag ¶ added in v0.2.0
type Flag struct {
// Name - required (long version) of the flag, lowercase (with hyphens)
Name string
// Short - required (single character, lowercase) of the flag
Short string
// Desc - required, a short description of the flag
Desc string
// Type - required the type of the flag
Type FlagType
// Value - optional default value of the flag
Value any
}
type FormatJSON ¶
type FormatJSON struct{}
FormatJSON formats given string to a JSON with Indent.
func (FormatJSON) Alias ¶ added in v0.2.0
func (p FormatJSON) Alias() []string
func (FormatJSON) Description ¶ added in v0.2.0
func (p FormatJSON) Description() string
func (FormatJSON) FilterValue ¶ added in v0.2.0
func (p FormatJSON) FilterValue() string
func (FormatJSON) Flags ¶ added in v0.2.0
func (p FormatJSON) Flags() []Flag
func (FormatJSON) Name ¶ added in v0.2.0
func (p FormatJSON) Name() string
func (FormatJSON) Title ¶ added in v0.2.0
func (p FormatJSON) Title() string
type HTMLDecode ¶ added in v0.2.0
type HTMLDecode struct{}
HTMLDecode unescapes HTML to string
func (HTMLDecode) Alias ¶ added in v0.2.0
func (p HTMLDecode) Alias() []string
func (HTMLDecode) Description ¶ added in v0.2.0
func (p HTMLDecode) Description() string
func (HTMLDecode) FilterValue ¶ added in v0.2.0
func (p HTMLDecode) FilterValue() string
func (HTMLDecode) Flags ¶ added in v0.2.0
func (p HTMLDecode) Flags() []Flag
func (HTMLDecode) Name ¶ added in v0.2.0
func (p HTMLDecode) Name() string
func (HTMLDecode) Title ¶ added in v0.2.0
func (p HTMLDecode) Title() string
type HTMLEncode ¶ added in v0.2.0
type HTMLEncode struct{}
HTMLEncode escapes string to HTML
func (HTMLEncode) Alias ¶ added in v0.2.0
func (p HTMLEncode) Alias() []string
func (HTMLEncode) Description ¶ added in v0.2.0
func (p HTMLEncode) Description() string
func (HTMLEncode) FilterValue ¶ added in v0.2.0
func (p HTMLEncode) FilterValue() string
func (HTMLEncode) Flags ¶ added in v0.2.0
func (p HTMLEncode) Flags() []Flag
func (HTMLEncode) Name ¶ added in v0.2.0
func (p HTMLEncode) Name() string
func (HTMLEncode) Title ¶ added in v0.2.0
func (p HTMLEncode) Title() string
type HexDecode ¶ added in v0.2.0
type HexDecode struct{}
HexDecode decodes hexadecimal to string
func (HexDecode) Description ¶ added in v0.2.0
func (HexDecode) FilterValue ¶ added in v0.2.0
func (HexDecode) GetStreamingConfig ¶ added in v0.2.29
func (p HexDecode) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for buffered processing
type HexEncode ¶ added in v0.2.0
type HexEncode struct{}
HexEncode encodes string to hexadecimal
func (HexEncode) Description ¶ added in v0.2.0
func (HexEncode) FilterValue ¶ added in v0.2.0
func (HexEncode) GetStreamingConfig ¶ added in v0.2.29
func (p HexEncode) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for chunked processing
type HexToRGB ¶
type HexToRGB struct{}
HexToRGB converts hex color code to R, G, B codes here we are using data library helper.
func (HexToRGB) Description ¶ added in v0.2.0
func (HexToRGB) FilterValue ¶ added in v0.2.0
type JSONEscape ¶ added in v0.2.8
type JSONEscape struct{}
JSONEscape escape given string to a JSON with Indent.
func (JSONEscape) Alias ¶ added in v0.2.8
func (p JSONEscape) Alias() []string
func (JSONEscape) Description ¶ added in v0.2.8
func (p JSONEscape) Description() string
func (JSONEscape) FilterValue ¶ added in v0.2.8
func (p JSONEscape) FilterValue() string
func (JSONEscape) Flags ¶ added in v0.2.8
func (p JSONEscape) Flags() []Flag
func (JSONEscape) Name ¶ added in v0.2.8
func (p JSONEscape) Name() string
func (JSONEscape) Title ¶ added in v0.2.8
func (p JSONEscape) Title() string
type JSONToMSGPACK ¶ added in v0.2.7
type JSONToMSGPACK struct{}
JSONToMSGPACK converts JSON to MSGPACK string.
func (JSONToMSGPACK) Alias ¶ added in v0.2.7
func (p JSONToMSGPACK) Alias() []string
func (JSONToMSGPACK) Description ¶ added in v0.2.7
func (p JSONToMSGPACK) Description() string
func (JSONToMSGPACK) FilterValue ¶ added in v0.2.7
func (p JSONToMSGPACK) FilterValue() string
func (JSONToMSGPACK) Flags ¶ added in v0.2.7
func (p JSONToMSGPACK) Flags() []Flag
func (JSONToMSGPACK) Name ¶ added in v0.2.7
func (p JSONToMSGPACK) Name() string
func (JSONToMSGPACK) Title ¶ added in v0.2.7
func (p JSONToMSGPACK) Title() string
type JSONToYAML ¶
type JSONToYAML struct{}
JSONToYAML converts JSON to YAML string.
func (JSONToYAML) Alias ¶ added in v0.2.0
func (p JSONToYAML) Alias() []string
func (JSONToYAML) Description ¶ added in v0.2.0
func (p JSONToYAML) Description() string
func (JSONToYAML) FilterValue ¶ added in v0.2.0
func (p JSONToYAML) FilterValue() string
func (JSONToYAML) Flags ¶ added in v0.2.0
func (p JSONToYAML) Flags() []Flag
func (JSONToYAML) Name ¶ added in v0.2.0
func (p JSONToYAML) Name() string
func (JSONToYAML) Title ¶ added in v0.2.0
func (p JSONToYAML) Title() string
type JSONUnescape ¶ added in v0.2.8
type JSONUnescape struct{}
JSONUnescape unescapes given string to a JSON with Indent.
func (JSONUnescape) Alias ¶ added in v0.2.8
func (p JSONUnescape) Alias() []string
func (JSONUnescape) Description ¶ added in v0.2.8
func (p JSONUnescape) Description() string
func (JSONUnescape) FilterValue ¶ added in v0.2.8
func (p JSONUnescape) FilterValue() string
func (JSONUnescape) Flags ¶ added in v0.2.8
func (p JSONUnescape) Flags() []Flag
func (JSONUnescape) Name ¶ added in v0.2.8
func (p JSONUnescape) Name() string
func (JSONUnescape) Title ¶ added in v0.2.8
func (p JSONUnescape) Title() string
type Kebab ¶ added in v0.2.0
type Kebab struct{}
Kebab convert string to kebab-case. Example: "this is string" to "this-is-string".
func (Kebab) Description ¶ added in v0.2.0
func (Kebab) FilterValue ¶ added in v0.2.0
type Lower ¶ added in v0.2.0
type Lower struct{}
Lower converts a string to lower case. Example: "THIS IS STRING" to "this is string".
func (Lower) Description ¶ added in v0.2.0
func (Lower) FilterValue ¶ added in v0.2.0
func (Lower) GetStreamingConfig ¶ added in v0.2.29
func (p Lower) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for chunked processing
type MD5 ¶ added in v0.2.0
type MD5 struct{}
MD5 encodes string to MD5.
func (MD5) Description ¶ added in v0.2.0
func (MD5) FilterValue ¶ added in v0.2.0
func (MD5) GetStreamingConfig ¶ added in v0.2.29
func (p MD5) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for optimized streaming
type MSGPACKToJSON ¶ added in v0.2.7
type MSGPACKToJSON struct{}
MSGPACKToJSON converts MSGPACK to JSON string.
func (MSGPACKToJSON) Alias ¶ added in v0.2.7
func (p MSGPACKToJSON) Alias() []string
func (MSGPACKToJSON) Description ¶ added in v0.2.7
func (p MSGPACKToJSON) Description() string
func (MSGPACKToJSON) FilterValue ¶ added in v0.2.7
func (p MSGPACKToJSON) FilterValue() string
func (MSGPACKToJSON) Flags ¶ added in v0.2.7
func (p MSGPACKToJSON) Flags() []Flag
func (MSGPACKToJSON) Name ¶ added in v0.2.7
func (p MSGPACKToJSON) Name() string
func (MSGPACKToJSON) Title ¶ added in v0.2.7
func (p MSGPACKToJSON) Title() string
type Markdown ¶ added in v0.2.0
type Markdown struct{}
Markdown converts Markdown to HTML.
func (Markdown) Description ¶ added in v0.2.0
func (Markdown) FilterValue ¶ added in v0.2.0
type MorseCodeDecode ¶ added in v0.2.17
type MorseCodeDecode struct{}
MorseCodeDecode decodes Morse Code to string
func (MorseCodeDecode) Alias ¶ added in v0.2.17
func (p MorseCodeDecode) Alias() []string
func (MorseCodeDecode) Description ¶ added in v0.2.17
func (p MorseCodeDecode) Description() string
func (MorseCodeDecode) FilterValue ¶ added in v0.2.17
func (p MorseCodeDecode) FilterValue() string
func (MorseCodeDecode) Flags ¶ added in v0.2.17
func (p MorseCodeDecode) Flags() []Flag
func (MorseCodeDecode) Name ¶ added in v0.2.17
func (p MorseCodeDecode) Name() string
func (MorseCodeDecode) Title ¶ added in v0.2.17
func (p MorseCodeDecode) Title() string
type MorseCodeEncode ¶ added in v0.2.17
type MorseCodeEncode struct{}
MorseCodeEncode encodes string to Morse Code.
func (MorseCodeEncode) Alias ¶ added in v0.2.17
func (p MorseCodeEncode) Alias() []string
func (MorseCodeEncode) Description ¶ added in v0.2.17
func (p MorseCodeEncode) Description() string
func (MorseCodeEncode) FilterValue ¶ added in v0.2.17
func (p MorseCodeEncode) FilterValue() string
func (MorseCodeEncode) Flags ¶ added in v0.2.17
func (p MorseCodeEncode) Flags() []Flag
func (MorseCodeEncode) Name ¶ added in v0.2.17
func (p MorseCodeEncode) Name() string
func (MorseCodeEncode) Title ¶ added in v0.2.17
func (p MorseCodeEncode) Title() string
type NumberLines ¶ added in v0.2.28
type NumberLines struct{}
NumberLines Prepends consecutive number to each line of input
func (NumberLines) Alias ¶ added in v0.2.28
func (p NumberLines) Alias() []string
func (NumberLines) Description ¶ added in v0.2.28
func (p NumberLines) Description() string
func (NumberLines) FilterValue ¶ added in v0.2.28
func (p NumberLines) FilterValue() string
func (NumberLines) Flags ¶ added in v0.2.28
func (p NumberLines) Flags() []Flag
func (NumberLines) GetStreamingConfig ¶ added in v0.2.29
func (p NumberLines) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for line-by-line processing
func (NumberLines) Name ¶ added in v0.2.28
func (p NumberLines) Name() string
func (NumberLines) Title ¶ added in v0.2.28
func (p NumberLines) Title() string
type Pascal ¶ added in v0.2.23
type Pascal struct{}
Pascal convert string to CamelCase. Example: "this is string" to "ThisIsString".
func (Pascal) Description ¶ added in v0.2.23
func (Pascal) FilterValue ¶ added in v0.2.23
type Processor ¶ added in v0.2.0
type Processor interface {
// Name is the name of a processor used as the CLI command, must be one lowercase word,
// hyphens are allowed
Name() string
// Alias is an optional array of alias names for the processor
Alias() []string
// Transform is the text transformation function, implemented by the processor
Transform(data []byte, opts ...Flag) (string, error)
// Flags are flags that could be used to transform the text
Flags() []Flag
}
type QRCode ¶ added in v0.2.30
type QRCode struct{}
func (QRCode) Description ¶ added in v0.2.30
func (QRCode) FilterValue ¶ added in v0.2.30
func (QRCode) GetStreamingConfig ¶ added in v0.2.30
func (p QRCode) GetStreamingConfig() StreamingConfig
type ROT13 ¶ added in v0.2.22
type ROT13 struct{}
ROT13 converts string with ROT13 cypher. https://en.wikipedia.org/wiki/ROT13
func (ROT13) Description ¶ added in v0.2.22
func (ROT13) FilterValue ¶ added in v0.2.22
type RemoveNewLines ¶ added in v0.2.16
type RemoveNewLines struct{}
RemoveNewLines removes newlines from string.
func (RemoveNewLines) Alias ¶ added in v0.2.16
func (p RemoveNewLines) Alias() []string
func (RemoveNewLines) Description ¶ added in v0.2.16
func (p RemoveNewLines) Description() string
func (RemoveNewLines) FilterValue ¶ added in v0.2.16
func (p RemoveNewLines) FilterValue() string
func (RemoveNewLines) Flags ¶ added in v0.2.16
func (p RemoveNewLines) Flags() []Flag
func (RemoveNewLines) Name ¶ added in v0.2.16
func (p RemoveNewLines) Name() string
func (RemoveNewLines) Title ¶ added in v0.2.16
func (p RemoveNewLines) Title() string
type RemoveSpaces ¶ added in v0.2.16
type RemoveSpaces struct{}
RemoveSpaces removes all the spaces from string.
func (RemoveSpaces) Alias ¶ added in v0.2.16
func (p RemoveSpaces) Alias() []string
func (RemoveSpaces) Description ¶ added in v0.2.16
func (p RemoveSpaces) Description() string
func (RemoveSpaces) FilterValue ¶ added in v0.2.16
func (p RemoveSpaces) FilterValue() string
func (RemoveSpaces) Flags ¶ added in v0.2.16
func (p RemoveSpaces) Flags() []Flag
func (RemoveSpaces) Name ¶ added in v0.2.16
func (p RemoveSpaces) Name() string
func (RemoveSpaces) Title ¶ added in v0.2.16
func (p RemoveSpaces) Title() string
type Reverse ¶ added in v0.2.0
type Reverse struct{}
Reverse reverses a given string Example: "test" to "tset".
func (Reverse) Description ¶ added in v0.2.0
func (Reverse) FilterValue ¶ added in v0.2.0
type ReverseLines ¶ added in v0.2.11
type ReverseLines struct{}
ReverseLines sorts given lines, in random order.
func (ReverseLines) Alias ¶ added in v0.2.11
func (p ReverseLines) Alias() []string
func (ReverseLines) Description ¶ added in v0.2.11
func (p ReverseLines) Description() string
func (ReverseLines) FilterValue ¶ added in v0.2.11
func (p ReverseLines) FilterValue() string
func (ReverseLines) Flags ¶ added in v0.2.11
func (p ReverseLines) Flags() []Flag
func (ReverseLines) GetStreamingConfig ¶ added in v0.2.29
func (p ReverseLines) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for line processing
func (ReverseLines) Name ¶ added in v0.2.11
func (p ReverseLines) Name() string
func (ReverseLines) Title ¶ added in v0.2.11
func (p ReverseLines) Title() string
type SHA1 ¶ added in v0.2.0
type SHA1 struct{}
SHA1 encodes string to SHA-1.
func (SHA1) Description ¶ added in v0.2.0
func (SHA1) FilterValue ¶ added in v0.2.0
func (SHA1) GetStreamingConfig ¶ added in v0.2.29
func (p SHA1) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for optimized streaming
type SHA224 ¶ added in v0.2.17
type SHA224 struct{}
SHA224 encode string to SHA-224.
func (SHA224) Description ¶ added in v0.2.17
func (SHA224) FilterValue ¶ added in v0.2.17
func (SHA224) GetStreamingConfig ¶ added in v0.2.29
func (p SHA224) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for optimized streaming
type SHA256 ¶ added in v0.2.0
type SHA256 struct{}
SHA256 encodes string to SHA-256.
func (SHA256) Description ¶ added in v0.2.0
func (SHA256) FilterValue ¶ added in v0.2.0
func (SHA256) GetStreamingConfig ¶ added in v0.2.29
func (p SHA256) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for optimized streaming
type SHA384 ¶ added in v0.2.17
type SHA384 struct{}
SHA384 encodes string to SHA-384.
func (SHA384) Description ¶ added in v0.2.17
func (SHA384) FilterValue ¶ added in v0.2.17
func (SHA384) GetStreamingConfig ¶ added in v0.2.29
func (p SHA384) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for optimized streaming
type SHA512 ¶ added in v0.2.0
type SHA512 struct{}
SHA512 encodes string to SHA-512.
func (SHA512) Description ¶ added in v0.2.0
func (SHA512) FilterValue ¶ added in v0.2.0
func (SHA512) GetStreamingConfig ¶ added in v0.2.29
func (p SHA512) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for optimized streaming
type ShuffleLines ¶ added in v0.2.9
type ShuffleLines struct{}
ShuffleLines sorts given lines, in random order.
func (ShuffleLines) Alias ¶ added in v0.2.9
func (p ShuffleLines) Alias() []string
func (ShuffleLines) Description ¶ added in v0.2.9
func (p ShuffleLines) Description() string
func (ShuffleLines) FilterValue ¶ added in v0.2.9
func (p ShuffleLines) FilterValue() string
func (ShuffleLines) Flags ¶ added in v0.2.9
func (p ShuffleLines) Flags() []Flag
func (ShuffleLines) Name ¶ added in v0.2.9
func (p ShuffleLines) Name() string
func (ShuffleLines) Title ¶ added in v0.2.9
func (p ShuffleLines) Title() string
type Slug ¶ added in v0.2.0
type Slug struct{}
Slug convert string to StringToSlug. It's similar to Kebab case but URL Friendly. Example: "this is string" to "this-is-string".
func (Slug) Description ¶ added in v0.2.0
func (Slug) FilterValue ¶ added in v0.2.0
type Snake ¶ added in v0.2.0
type Snake struct{}
Snake convert string to snake_case. Example: "this is string" to "this_is_string".
func (Snake) Description ¶ added in v0.2.0
func (Snake) FilterValue ¶ added in v0.2.0
type SortLines ¶
type SortLines struct{}
SortLines sorts given lines, it's not a natural sort. Example: 2\n 1\n -> 1\n 2\n.
func (SortLines) Description ¶ added in v0.2.0
func (SortLines) FilterValue ¶ added in v0.2.0
func (SortLines) GetStreamingConfig ¶ added in v0.2.29
func (p SortLines) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for line processing
type StreamingCapable ¶ added in v0.2.29
type StreamingCapable interface {
CanStream() bool
}
type StreamingConfig ¶ added in v0.2.29
type StreamingConfig struct {
// ChunkSize defines the size of chunks to read from input (default: 64KB)
ChunkSize int
// BufferOutput whether to buffer output before writing (useful for processors that need full input)
BufferOutput bool
// LineByLine whether to process input line by line (useful for line-based processors)
LineByLine bool
}
StreamingConfig defines how a processor should handle streaming
type StreamingProcessor ¶ added in v0.2.29
type Title ¶ added in v0.2.0
type Title struct{}
Title convert string to title case. Example: "this is string" to "This Is String".
func (Title) Description ¶ added in v0.2.0
func (Title) FilterValue ¶ added in v0.2.0
type URLDecode ¶
type URLDecode struct{}
URLDecode decode url string.
func (URLDecode) Description ¶ added in v0.2.0
func (URLDecode) FilterValue ¶ added in v0.2.0
type URLEncode ¶
type URLEncode struct{}
URLEncode encode url string.
func (URLEncode) Description ¶ added in v0.2.0
func (URLEncode) FilterValue ¶ added in v0.2.0
type UniqueLines ¶ added in v0.2.11
type UniqueLines struct{}
UniqueLines sorts given lines, in random order.
func (UniqueLines) Alias ¶ added in v0.2.11
func (p UniqueLines) Alias() []string
func (UniqueLines) Description ¶ added in v0.2.11
func (p UniqueLines) Description() string
func (UniqueLines) FilterValue ¶ added in v0.2.11
func (p UniqueLines) FilterValue() string
func (UniqueLines) Flags ¶ added in v0.2.11
func (p UniqueLines) Flags() []Flag
func (UniqueLines) GetStreamingConfig ¶ added in v0.2.29
func (p UniqueLines) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for line processing
func (UniqueLines) Name ¶ added in v0.2.11
func (p UniqueLines) Name() string
func (UniqueLines) Title ¶ added in v0.2.11
func (p UniqueLines) Title() string
type Upper ¶ added in v0.2.0
type Upper struct{}
Upper convert string to upper case. Example: "this is string" to "THIS IS STRING".
func (Upper) Description ¶ added in v0.2.0
func (Upper) FilterValue ¶ added in v0.2.0
func (Upper) GetStreamingConfig ¶ added in v0.2.29
func (p Upper) GetStreamingConfig() StreamingConfig
Implement ConfigurableStreamingProcessor interface for chunked processing
type XXH32 ¶ added in v0.2.28
type XXH32 struct{}
XX32 encodes string to XXH32
func (XXH32) Description ¶ added in v0.2.28
func (XXH32) FilterValue ¶ added in v0.2.28
type XXH64 ¶ added in v0.2.27
type XXH64 struct{}
XXH64 encodes string to XXH64
func (XXH64) Description ¶ added in v0.2.27
func (XXH64) FilterValue ¶ added in v0.2.27
type XXH128 ¶ added in v0.2.28
type XXH128 struct{}
XX128 encodes string to XXH32
func (XXH128) Description ¶ added in v0.2.28
func (XXH128) FilterValue ¶ added in v0.2.28
type YAMLToJSON ¶
type YAMLToJSON struct{}
YAMLToJSON converts YAML to JSON string with formatted output.
func (YAMLToJSON) Alias ¶ added in v0.2.0
func (p YAMLToJSON) Alias() []string
func (YAMLToJSON) Description ¶ added in v0.2.0
func (p YAMLToJSON) Description() string
func (YAMLToJSON) FilterValue ¶ added in v0.2.0
func (p YAMLToJSON) FilterValue() string
func (YAMLToJSON) Flags ¶ added in v0.2.0
func (p YAMLToJSON) Flags() []Flag
func (YAMLToJSON) Name ¶ added in v0.2.0
func (p YAMLToJSON) Name() string
func (YAMLToJSON) Title ¶ added in v0.2.0
func (p YAMLToJSON) Title() string
type Zeropad ¶ added in v0.2.0
type Zeropad struct{}
Zeropad is an Example processor to show how to add text processors, it checks if the data is a number and pads it with zeros Example implements 'Item' and 'DefaultItem' from package 'github.com/charmbracelet/bubbles/list' to work with the UI, and `Processor` from this package to do the text transformation and generation of the CLI commands After implementing add the struct to List.